<?php 

function my_plugin_menu() {
  add_options_page('Youtube Profile Field Options', 'Youtube Profile Field', 'manage_options', 'youtube-profile-field', 'my_plugin_options');
}

function youtubeprofile_init(){
	register_setting( 'youtubeprofile_options', 'youtubeprofile', 'youtubeprofile_options_validate');
} 

function youtubeprofile_page_styles() {
	wp_enqueue_style('youtubeprofile-css', WP_CONTENT_URL . '/plugins/' . plugin_basename(dirname(__FILE__)). '/youtube-admin-style.css');
}

function youtubeprofile_page_scripts() {
	if (isset($_GET['page']) && $_GET['page'] == "youtube-profile-field") {
		wp_enqueue_script('postbox');
		wp_enqueue_script('dashboard');
	}
}

add_action('admin_init', 'youtubeprofile_init');
add_action('admin_menu', 'my_plugin_menu');
add_action('admin_print_styles', 'youtubeprofile_page_styles');	
add_action('admin_print_scripts', 'youtubeprofile_page_scripts');


function my_plugin_options() { ?>
    
    <div class="wrap youtubeprofile">
    
    	<h2>Youtube Profile Field <small><?php _e("Options"); ?></small></h2>
        
        <form method="post" action="options.php">
        <?php settings_fields('youtubeprofile_options'); ?>
        <?php $options = get_option('youtubeprofile'); ?>
        
        <div class="postbox-container">
        <div class="metabox-holder">
        <div class="meta-box-sortables">
    
        
        <div class="postbox">
        
        <div class="handlediv"><br /></div>
        <h3 class="hndle"><span><?php _e("Options"); ?></span></h3>
        
        <div class="inside">
        
        
        <div class="box" style="margin-top: 20px;">
            <label><?php _e('Videos to show', 'youtubeprofile'); ?></label>
            <input type="text" name="youtubeprofile[count]" value="<?php echo $options['count']; ?>" />
            <small><?php _e('Can be overriden with a template tag or shortcode', 'youtubeprofile'); ?></small>
        </div>
                
        <div class="box">
            <label><?php _e('Width of the video', 'youtubeprofile'); ?></label>
            <input type="text" name="youtubeprofile[width]" value="<?php echo $options['width'];  ?>" />
            <small><?php _e('Youtube size: 560', 'youtubeprofile'); ?></small>
        </div>
        
        <div class="box">
            <label><?php _e('Height of the video', 'youtubeprofile'); ?></label>
            <input type="text" name="youtubeprofile[height]" value="<?php echo $options['height']; ?>" />
            <small><?php _e('Youtube size: 340', 'youtubeprofile'); ?></small>
        </div>
        
        <div class="box">
            <label><?php _e('Heading to titles', 'youtubeprofile'); ?></label>
            <input type="text" name="youtubeprofile[headingStart]" value="<?php echo $options['headingStart']; ?>" />
            <small><?php _e('&lt;h3&gt;, &lt;p&gt; or something else', 'youtubeprofile'); ?></small>
        </div>
        
        <div class="box">
            <label><?php _e('End heading', 'youtubeprofile'); ?></label>
            <input type="text" name="youtubeprofile[headingEnd]" value="<?php echo $options['headingEnd']; ?>" />
            <small><?php _e('&lt;/h3&gt;, &lt;/p&gt;', 'youtubeprofile'); ?></small>
        </div>
         
        <p class="submit" style="margin-left: 10px;">
        	<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
        </p>
        
        </div>
        </div>
        
        <!-- help -->
        
        <div class="postbox closed">
        
        <div class="handlediv" title="Click to toogle"><br /></div>
        <h3 class="hndle"><span><?php _e('Help', 'youtubeprofile'); ?></span></h3>
        
        <div class="inside">
        
        <div class="box">
        
            <div class="helpbox">
                <h4><?php _e('Recommended video sizes', 'youtubeprofile'); ?></h4>
                
                <ul>
                <li>480x295</li>
                <li>560x340</li>
                <li>640x385</li>
                <li>853x505</li>
                </ul>
            </div>  
            
            <div class="helpbox">
                <h4><?php _e('How to use in template files', 'youtubeprofile'); ?></h4>
                
                <code>
                    &lt;?php 
                    if ( function_exists('show_video') ) {
                    show_video($count, $userid);
                    }
                    ?&gt;
                </code> 
                
                <p><?php _e('It accept 2 parameters.', 'youtubeprofile'); ?></p>
                
                <p>
                    <code>$count</code> <em><small><?php _e('Optional', 'youtubeprofile'); ?></small></em> <br />
                    <?php _e('Number of videos you want to show. Will override the one entered in the options panel. 
                    If not entered, will it use the one from the options panel.', 'youtubeprofile'); ?>
                </p>
                
                <p>
                    <code>$userid</code> <em><small><?php _e('Optional', 'youtubeprofile'); ?></small></em> <br />
                    <?php _e("Choose want user you want to show videos from. You don't need to enter one if you use the function inside the loop. 
                    If you use it outside the loop you might want to enter one (or it will use ID 1).", "youtubeprofile"); ?>
                </p>
            </div>
            
            <div class="helpbox">
                <p>
                    <h4><?php _e('Example of usage', 'youtubeprofile'); ?></h4>
                    
                    <code>
                        &lt;?php 
                        if ( function_exists('show_video') ) {
                        show_video('', 2)
                        }
                        ?&gt;
                    </code> <br /><br />
                    
                    <?php _e('That will show videos from User 2 and show the number of videos entered in the options panel.', 'youtubeprofile'); ?>
                </p>
            </div>
            
            <div class="helpbox">
                <h4><?php _e('How to use in author.php', 'youtubeprofile'); ?></h4>
                
                <p><?php printf(__('To get the ID of the current user on author.php, do you first need to <a href="%s">Setup Author Information</a>', 'youtubeprofile'), 'http://codex.wordpress.org/Author_Templates#Setting_Up_for_Author_Information'); ?>
                <br />
                
                <?php _e('After that just use', 'youtubeprofile'); ?></p>
                
                <code>
                    &lt;?php 
                    if ( function_exists('show_video') ) {
                    show_video('', $curauth->ID)
                    }
                    ?&gt;
                </code>
            </div>
            
            <div class="helpbox">
            	<h4><?php _e('How to use in posts, pages and textwidgets', 'youtubeprofile'); ?></h4>
                
                <p>
                	<?php _e('You can use this shortcode if you want to display the videos in posts, pages or text widgets.', 'youtubeprofile'); ?>
                </p>
                
                <code>[youtube-user]</code>
                
                <p><?php _e('It will show 1 video. If you want to display more, just use', 'youtubeprofile'); ?></p>
                
                <code>[youtube-user display="3"]</code> <small><?php _e('3 is the number of videos', 'youtubeprofile'); ?></small>
                
                <p><?php _e('You can also show a specific video', 'youtubeprofile'); ?></p>
                
                <code>[youtube-user id="ql0kn-yI2OY"]</code> <small><?php _e('ql0kn-yI2OY is the video ID', 'youtubeprofile'); ?></small>
            </div>
            
        </div> <!-- end box -->
        
        </div>
        </div> <!-- end postbox help -->
        
        </div></div></div> <!-- end postbox container -->
        
        </form>

    </div> <!-- end wrap -->
  
<?php

}

// Sanitize and validate input. Accepts an array, return a sanitized array.
function youtubeprofile_options_validate($input) {
	$input['count'] =  intval($input['count']);
	$input['width'] =  intval($input['width']);
	$input['height'] =  intval($input['height']);
	return $input;
}

?>